==> lxqt-powermanagement-0.10.0.tar.xz: lxqt-powermanagement-0.10.0/src/translations/lxqt-powermanagement_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>Battery</name>
    <message>
        <source>Charging</source>
        <translation type="vanished">Φόρτιση</translation>
    </message>
    <message>
        <source>Discharging</source>
        <translation type="vanished">Αποφόρτιση</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation type="vanished">Άδεια</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation type="vanished">Γεμάτη</translation>
    </message>
    <message>
        <source>Pending charge</source>
        <translation type="vanished">Φορτίζεται</translation>
    </message>
    <message>
        <source>Pending discharge</source>
        <translation type="vanished">Αποφορτίζεται</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="vanished">Άγνωστο</translation>
    </message>
</context>
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="42"/>
        <source>Empty</source>
        <translation type="unfinished">Άδεια</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Discharging</source>
        <translation type="unfinished">Αποφόρτιση</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Fully charged</source>
        <translation type="unfinished">Γεμάτη</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="49"/>
        <source>Charging</source>
        <translation type="unfinished">Φόρτιση</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="58"/>
        <source>Lithium ion</source>
        <translation type="unfinished">Ιόντων λιθίου</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium polymer</source>
        <translation type="unfinished">Πολυμερούς λιθίου</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium iron phosphate</source>
        <translation type="unfinished">Λίθιου Φωσφορικού άλατος σιδήρου</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lead acid</source>
        <translation type="unfinished">Μολύβδου οξέος</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Nickel cadmium</source>
        <translation type="unfinished">Νικελίου καδμίου</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel metal hydride</source>
        <translation type="unfinished">Υβριδική νικελίου μετάλλου</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="71"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="80"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Primary battery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Mouse battery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Keyboard battery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Camera battery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Phone battery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Monitor battery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="99"/>
        <source>Unknown battery</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BatteryInfo</name>
    <message>
        <source>Power Management</source>
        <translation type="vanished">Διαχείριση ενέργειας</translation>
    </message>
    <message>
        <source>Battery info</source>
        <translation type="vanished">Πληροφορίες της μπαταρίας</translation>
    </message>
    <message>
        <source>Energy Now:</source>
        <translation type="vanished">Η τρέχουσα ενέργεια:</translation>
    </message>
    <message>
        <source>Updated:</source>
        <translation type="vanished">Ενημερωμένη:</translation>
    </message>
    <message>
        <source>Technology:</source>
        <translation type="vanished">Τεχνολογία:</translation>
    </message>
    <message>
        <source>Model:</source>
        <translation type="vanished">Μοντέλο:</translation>
    </message>
    <message>
        <source>Energy rate:</source>
        <translation type="vanished">Ρυθμός ενέργειας:</translation>
    </message>
    <message>
        <source>Voltage:</source>
        <translation type="vanished">Τάση:</translation>
    </message>
    <message>
        <source>Energy Full, Design:</source>
        <translation type="vanished">Πλήρης ενέργεια, σχεδιασμός:</translation>
    </message>
    <message>
        <source>Energy Full:</source>
        <translation type="vanished">Πλήρης ενέργεια:</translation>
    </message>
    <message>
        <source>State:</source>
        <translation type="vanished">Κατάσταση:</translation>
    </message>
    <message>
        <source>Lithium ion</source>
        <translation type="vanished">Ιόντων λιθίου</translation>
    </message>
    <message>
        <source>Lithium polymer</source>
        <translation type="vanished">Πολυμερούς λιθίου</translation>
    </message>
    <message>
        <source>Lithium iron phosphate</source>
        <translation type="vanished">Λίθιου Φωσφορικού άλατος σιδήρου</translation>
    </message>
    <message>
        <source>Lead acid</source>
        <translation type="vanished">Μολύβδου οξέος</translation>
    </message>
    <message>
        <source>Nickel cadmium</source>
        <translation type="vanished">Νικελίου καδμίου</translation>
    </message>
    <message>
        <source>Nickel metal hydride</source>
        <translation type="vanished">Υβριδική νικελίου μετάλλου</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="vanished">Άγνωστη</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="22"/>
        <source>Battery Info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation type="unfinished">Διαχείριση ενέργειας</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation type="unfinished">Κατάσταση:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation type="unfinished">Πλήρης ενέργεια:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation type="unfinished">Η τρέχουσα ενέργεια:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation type="unfinished">Ρυθμός ενέργειας:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation type="unfinished">Τεχνολογία:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation type="unfinished">Τάση:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="47"/>
        <source>No battery!</source>
        <translation>Καμιά μπαταρία!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>Το LXQT δεν μπόρεσε να βρει δεδομένα για οποιαδήποτε μπαταρία - η εποπτεία απενεργοποιήθηκε</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="113"/>
        <source>Power low!</source>
        <translation>Η ενέργεια είναι χαμηλή!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="125"/>
        <source>Suspending in %1 seconds</source>
        <translation>Αναστολή σε %1 δευτερόλεπτα</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="128"/>
        <source>Hibernating in %1 seconds</source>
        <translation>Νάρκωση σε %1 δευτερόλεπτα</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="131"/>
        <source>Shutting down in %1 seconds</source>
        <translation>Τερματισμός σε %1 δευτερόλεπτα</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcher</name>
    <message>
        <location filename="../idlenesswatcher.cpp" line="50"/>
        <source>LXQt Idleness watcher failed to start</source>
        <translation>Η εκκίνηση του επόπτη αδράνειας του LXQt απέτυχε</translation>
    </message>
    <message>
        <location filename="../idlenesswatcher.cpp" line="73"/>
        <source>D-Bus interface org.freedesktop.ScreenSaver is already registered</source>
        <translation>Η διεπαφή του D-Bus org.freedesktop.ScreenSaver έχει καταχωρηθεί ήδη</translation>
    </message>
    <message>
        <location filename="../idlenesswatcher.cpp" line="107"/>
        <source>The X11 Screensaver extension is not usable</source>
        <translation>Η επέκταση της προστασίας οθόνης X11 δεν μπορεί να χρησιμοποιηθεί</translation>
    </message>
    <message>
        <location filename="../idlenesswatcher.cpp" line="114"/>
        <source>Configure...</source>
        <translation>Διαμόρφωση...</translation>
    </message>
    <message>
        <location filename="../idlenesswatcher.cpp" line="179"/>
        <source>ERROR: Screen unlocked</source>
        <translation>ΣΦΑΛΜΑ: Οθόνη ξεκλείδωτη</translation>
    </message>
    <message>
        <location filename="../idlenesswatcher.cpp" line="181"/>
        <source>Locking program &quot;%1&quot; exited with error code %2</source>
        <translation>Το πρόγραμμα κλειδώματος «%1» τερματίστηκε με τον κωδικό σφάλματος %2</translation>
    </message>
    <message>
        <location filename="../idlenesswatcher.cpp" line="183"/>
        <source>Locking program &quot;%1&quot; crashed with error code %2</source>
        <translation>Το πρόγραμμα κλειδώματος «%1» κατέρρευσε με τον κωδικό σφάλματος %2</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="107"/>
        <source>Power Management</source>
        <translation>Διαχείριση ενέργειας</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="108"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Εκτελείτε την διαχείριση ενέργειας του LXQt για πρώτη φορά.
Μπορείτε να την διαμορφώσετε από τις ρυθμίσεις... 
</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="109"/>
        <source>Configure...</source>
        <translation>Διαμόρφωση...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="59"/>
        <source>Configure</source>
        <translation>Διαμόρφωση</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="61"/>
        <location filename="../trayicon.cpp" line="92"/>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="63"/>
        <source>Disable icon</source>
        <translation>Απενεργοποίηση του εικονιδίου</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="93"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="111"/>
        <source>LXQt Power Management info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="112"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="114"/>
        <source>Configure now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>discharging</source>
        <translation type="vanished">αποφορτίζεται</translation>
    </message>
    <message>
        <source>charging</source>
        <translation type="vanished">φορτίζεται</translation>
    </message>
    <message>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Powermanagement&lt;/b&gt;&lt;br/&gt;  - Powermanagement for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation type="vanished">&lt;p&gt;  &lt;b&gt;Διαχείριση ενέργειας του LXQt&lt;/b&gt;&lt;br/&gt;  - Διαχείριση της ενέργειας για το γραφικό περιβάλλον LXQt&lt;/p&gt;&lt;p&gt;  Συγγραφείς:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - και άλλοι από τα έργα Razor και LXQt&lt;/p&gt;&lt;p&gt;  Πνευματικά δικαιώματα &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement_0.14.1.orig.tar.xz: lxqt-powermanagement-0.14.1/src/translations/lxqt-powermanagement_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="42"/>
        <source>Empty</source>
        <translation>Αποφορτισμένος</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Discharging</source>
        <translation>Αποφόρτιση</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Fully charged</source>
        <translation>Φορτισμένος πλήρως</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="49"/>
        <source>Charging</source>
        <translation>Φόρτιση</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="58"/>
        <source>Lithium ion</source>
        <translation>Ιόντων λιθίου</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium polymer</source>
        <translation>Πολυμερούς λιθίου</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium iron phosphate</source>
        <translation>Λίθιου Φωσφορικού άλατος σιδήρου</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lead acid</source>
        <translation>Μολύβδου οξέος</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Nickel cadmium</source>
        <translation>Νικελίου καδμίου</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel metal hydride</source>
        <translation>Υβριδικός νικελίου μετάλλου</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="71"/>
        <source>Unknown</source>
        <translation>Άγνωστο</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="80"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Συσσωρευτής χειρός</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Σύστημα αδιάλειπτης τροφοδοσίας (UPS)</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Primary battery</source>
        <translation>Πρωτεύων συσσωρευτής</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Mouse battery</source>
        <translation>Συσσωρευτής ποντικιού</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Keyboard battery</source>
        <translation>Συσσωρευτής πληκτρολογίου</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Συσσωρευτής ποντικιού και πληκτρολογίου</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Camera battery</source>
        <translation>Συσσωρευτής κάμερας</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Phone battery</source>
        <translation>Συσσωρευτής τηλεφώνου</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Monitor battery</source>
        <translation>Συσσωρευτής οθόνης</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="99"/>
        <source>Unknown battery</source>
        <translation>Άγνωστος συσσωρευτής</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Διάλογος</translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>Πληροφορίες του συσσωρευτή</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Διαχείριση ενέργειας</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Θερμοκρασία:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Τύπος:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Κατάσταση:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Πλήρης ενέργεια σχεδιασμός:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Πλήρης ενέργεια:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Η τρέχουσα ενέργεια:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Ρυθμός ενέργειας:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Τεχνολογία:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Τάση:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Κατασκευαστής:</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>Ουδείς συσσωρευτής!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>Το LXQt δεν μπόρεσε να βρει δεδομένα κάποιου συσσωρευτή - η εποπτεία απενεργοποιήθηκε</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="114"/>
        <source>Power low!</source>
        <translation>Η ενέργεια είναι χαμηλή!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="126"/>
        <source>Suspending in %n second(s)</source>
        <translation>
            <numerusform>Αναστολή σε %n δευτερόλεπτο(α)</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="129"/>
        <source>Hibernating in %n second(s)</source>
        <translation>
            <numerusform>Νάρκωση σε %n δευτερόλεπτο(α)</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="132"/>
        <source>Shutting down in %n second(s)</source>
        <translation>
            <numerusform>Τερματισμός σε %n δευτερόλεπτο(α)</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="112"/>
        <source>Power Management</source>
        <translation>Διαχείριση ενέργειας</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="113"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Εκτελείτε την διαχείριση ενέργειας του LXQt για πρώτη φορά.
Μπορείτε να την διαμορφώσετε από τις ρυθμίσεις... 
</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="114"/>
        <source>Configure...</source>
        <translation>Διαμόρφωση...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="61"/>
        <source>Configure</source>
        <translation>Διαμόρφωση</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="63"/>
        <location filename="../trayicon.cpp" line="94"/>
        <source>About</source>
        <translation>Σχετικά</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="65"/>
        <source>Disable icon</source>
        <translation>Απενεργοποίηση του εικονιδίου</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="95"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;Διαχείριση ενέργειας LXQt&lt;/b&gt;&lt;br/&gt;  - Διαχείριση ενέργειας του περιβάλλοντος εργασίας LXQt&lt;/p&gt;&lt;p&gt;  Συγγραφείς:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - και λοιποί από τα έργα Razor και LXQt&lt;/p&gt;&lt;p&gt;  Πνευματικά δικαιώματα &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="113"/>
        <source>LXQt Power Management info</source>
        <translation>Πληροφορίες της διαχείρισης ενέργειας του LXQt</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="114"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>Το εικονίδιο στο πλαίσο συστήματος μπορεί να (επαν)ενεργοποιηθεί από το &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="116"/>
        <source>Configure now</source>
        <translation>Διαμόρφωση τώρα</translation>
    </message>
</context>
</TS>
